16.96. cdist-type__package_luarocks(7) — cdist 4.11.0 documentation

# 16.96. cdist-type__package_luarocks(7)

## 16.96.1. NAME

cdist-type__package_luarocks - Manage luarocks packages

## 16.96.2. DESCRIPTION

LuaRocks is a deployment and management system for Lua modules.

## 16.96.3. REQUIRED PARAMETERS

None

## 16.96.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 16.96.5. EXAMPLES

    # Ensure luasocket is installed
    __package_luarocks luasocket --state present

    # Remove package
    __package_luarocks luasocket --state absent

## 16.96.6. SEE ALSO

cdist-type__package(7)

## 16.96.7. AUTHORS

Christian G. Warden <cwarden@xerus.org>

## 16.96.8. COPYING

Copyright (C) 2012 SwellPath, Inc. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.